Unit VAD36api;
{ ========================================================================== }
{ =   Lynx Tecnologia Eletrnica Ltda.                                     = }
{ =   Projeto:   Drivers / Windows 95                   Data: 13/mai/1999  = }
{ =   Programa:  Teste do driver VAD36D da CAD12/36 para Windows 95.       = }
{ =   Mdulo:    VAD36api                                                  = }
{ =   Autor:     Lauro                                                     = }
{ =   Descrio: Acesso s primitivas do driver VAD36D.VXD                 = }
{ =   Verso:    1.0                                                       = }
{ ========================================================================== }

{-------------------------  Descrio da Interface  -------------------------}
Interface
  Uses Windows;

{ ===================================================== }
{ =              Declarao de constantes             = }
{ ===================================================== }

  Const {---------- Constantes referentes a configurao padro das placas --}
    sbaCAD = $380;   { Endereo base padro da CAD12/36 }
    sirCAD = 5;      { Interrupo padro da CAD12/36 }

  Const {---------------------------------- ieXXXX: Interrupt error status --}
    ieNoError        = 0;   { No error }
    ieIntOverrun     = 1;   { Interrupt overrun }
    ieAD_Error       = 2;   { A/D error }
    ieBufOverrun     = 3;   { Buffer list overrun }
    ieVPICD_Error    = 4;   { VPICD cant virtualize IRQ }
    ieEndAcquisition = 5;   { End of acquisition }
    ieDriver         = 100; { Erro de acesso ao driver }
    ieAcqStop        = 101; { Aquisio no est ativa }
    ieBufSize        = 102; { Dimenso errada do buffer }

  Const {------------------ Codigos de ganho das entrada A/D da CAD12/36 --}
    cBi10v0  = $f0;      { -10.0 a 10.0 V }
    cUni10v0 = $70;      {   0.0 a 10.0 V }
    cBi5v0   = $e0;      {  -5.0 a  5.0 V }
    cUni5v0  = $60;      {   0.0 a  5.0 V }
    cBi2v0   = $d0;      {  -2.0 a  2.0 V }
    cUni2v0  = $50;      {   0.0 a  2.0 V }


{ ===================================================== }
{ =     Declarao de tipos e variveis pblicas      = }
{ ===================================================== }

  Const
    cBufSize = 16384;     { Tamanho do buffer em bytes }

  Type {--------------------- Parmetro de sada da VAD36D_GetAcquiredData --}
    TpBufArray = array [0..cBufSize-1] of smallint;
    TpAcquiredData = record
      ieStatus: byte;       { Status da aquisio }
      nSamples: dword;      { Nmero de amostras aquisitadas por canal }
      nSampGot: dword;      { Mmero de amostras transferidas por canal }
      iLast   : dword;      { last sample time order in the user buffer }
      UserBuf : array [0..cBufSize-1] of smallint;
    end;


{ ========================================================================== }
{ =                     Primitivas do driver VAD36D                        = }
{ ========================================================================== }

  {-- Primitivas de controle de acesso e iniciao --}
  Function  VAD36D_W32_Open: WordBool; stdcall;
  Procedure VAD36D_W32_Close; stdcall;
  Function  VAD36D_GetVersion: word; stdcall;
  Function  VAD36D_InitCard (AbaCard: word; AIntNo: byte): WordBool; stdcall;

  {-- Primitivas de gerais do driver --}
  Procedure VAD36D_SetGain (GainCode: byte); stdcall;
  Function  VAD36D_ReadAI (Channel: byte; Var Value: smallint): WordBool; stdcall;
  Function  VAD36D_ReadDI: word; stdcall;
  Function  VAD36D_ReadDO: word; stdcall;
  Procedure VAD36D_WriteDO (Value: word); stdcall;
  Procedure VAD36D_ProgTimer (Channel, Mode: byte; Count: word); stdcall;
  Function  VAD36D_ReadTimer (Channel: byte): word; stdcall;

  {-- Primitivas da aquisio por interrupo --}
  Procedure VAD36D_ClearCM; stdcall;
  Procedure VAD36D_WriteCM (Channel, GainCode: byte); stdcall;
  Function  VAD36D_StartAcquisition (AFreqAq: single; AnSamples: longint): WordBool; stdcall;
  Procedure VAD36D_StopAcquisition; stdcall;
  Function  VAD36D_GetAcquiredData (Var AcquiredData: TpAcquiredData): byte; stdcall;
  Function  VAD36D_GetSamples (Var ErrorCode, iSample, nSampRead: longint; BufSize: longint;
                               Var UserBuffer: TpBufArray): boolean; stdcall;


{--------------------------  Bloco de Implementao  ------------------------}
Implementation


{ ========================================================================== }
{ =              Primitivas de controle de acesso ao driver                = }
{ ========================================================================== }

{----------------------------------------- Carrega o driver VxD VAD36D.VXD --}
Function VAD36D_W32_Open; stdcall; external 'VAD36D.DLL';

{------------------------------------------- Fecha o driver VxD VAD36D.VXD --}
Procedure VAD36D_W32_Close; stdcall; external 'VAD36D.DLL';

{------------------- Devolve a verso do VAD36D: MSB: verso; LSB: reviso --}
Function VAD36D_GetVersion; stdcall; external 'VAD36D.DLL';

{--------------------------------------------- Inicia a placa A/D CAD12/36 --}
Function VAD36D_InitCard; stdcall; external 'VAD36D.DLL';

{--------------------------------- Programa o ganho de entrada da CAD12/36 --}
Procedure VAD36D_SetGain; stdcall; external 'VAD36D.DLL';

{------------------------------------------- L canal de entrada analgica --}
Function VAD36D_ReadAI; stdcall; external 'VAD36D.DLL';

{---------------- Leitura dos ports P0 e P1 de entrada digital da CAD12/36 --}
Function VAD36D_ReadDI; stdcall; external 'VAD36D.DLL';

{------------- Retorna ltimo valor escritos nos ports P0 e P1 da CAD12/36 --}
Function VAD36D_ReadDO; stdcall; external 'VAD36D.DLL';

{------------------ Escreve nos ports P0 e P1 de sada digital da CAD12/36 --}
Procedure VAD36D_WriteDO; stdcall; external 'VAD36D.DLL';

{-------------------------------------------- Programa o Timer da CAD12/36 --}
Procedure VAD36D_ProgTimer; stdcall; external 'VAD36D.DLL';

{------------------------- Escreve no port P0 demsada digital da CAD12/36 --}
Function VAD36D_ReadTimer; stdcall; external 'VAD36D.DLL';

{----------------------------------------------- Limpa a memria de canais --}
Procedure VAD36D_ClearCM; stdcall; external 'VAD36D.DLL';

{-------------------------------------- Programa memria de canais virtual --}
Procedure VAD36D_WriteCM; stdcall; external 'VAD36D.DLL';

{---------------------------------------- Inicia aquisio por interrupo --}
Function VAD36D_StartAcquisition; stdcall; external 'VAD36D.DLL';

{--------------------------------------- Encerra aquisio por interrupo --}
Procedure VAD36D_StopAcquisition; stdcall; external 'VAD36D.DLL';

{------------------------------------- L o nmero de amostras aquisitadas --}
{ Informa se h dados novos aquisitados. Veja ieXXXX. O status de erro      }
{ resetado aps a chamada desta primitiva.                                   }
Function VAD36D_GetAcquiredData; stdcall; external 'VAD36D.DLL';

{------------------------------------- Prepara a aquisio por interrupo --}
Function VAD36D_GetSamples; stdcall; external 'VAD36D.DLL';


{ ===================================================== }
{ =            Rotina de iniciao do mdulo          = }
{ ===================================================== }

end.

